@@ -1,6 +1,6 @@
 package Reply::Plugin::ReadLine;
 our $AUTHORITY = 'cpan:DOY';
-$Reply::Plugin::ReadLine::VERSION = '0.39';
+$Reply::Plugin::ReadLine::VERSION = '0.40';
 use strict;
 use warnings;
 # ABSTRACT: use Term::ReadLine for user input
@@ -144,13 +144,13 @@ Reply::Plugin::ReadLine - use Term::ReadLine for user input
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
   ; .replyrc
   [ReadLine]
-  history_file = '.hist'
+  history_file = .hist
   history_length = 100
 
 =head1 DESCRIPTION
